"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const dom_1 = require("./dom");
const SerializedHighlight_1 = require("./SerializedHighlight");
exports.FOCUS_CSS = 'focus';
class Highlight {
    constructor(range, data) {
        this._elements = [];
        this.range = range;
        this.data = Object.assign({}, data, { 
            // TODO - something more random here
            id: data.id || (new Date()).getTime().toString() });
    }
    get id() {
        return this.data.id;
    }
    get content() {
        return this.data.content;
    }
    set elements(elements) {
        if (this.elements.length > 0) {
            throw new Error(`Hightlight elements aren't reloadable`);
        }
        this._elements = elements;
        this.loadStyle();
    }
    get elements() {
        return this._elements;
    }
    setStyle(style) {
        this.removeStyle();
        this.data.style = style;
        this.loadStyle();
    }
    getStyle() {
        return this.data.style;
    }
    removeStyle() {
        const { style } = this.data;
        if (style) {
            this.elements.forEach((element) => element.classList.remove(style));
            delete this.data.style;
        }
    }
    isAttached() {
        // TODO - check and see if these are in the dom
        return this.elements.length > 0;
    }
    scrollTo(handler) {
        if (!this.isAttached()) {
            return this;
        }
        else if (handler) {
            handler(this.elements);
        }
        else {
            this.elements[0].scrollIntoView();
        }
        return this;
    }
    focus() {
        this.elements.forEach((el) => el.classList.add(exports.FOCUS_CSS));
        return this;
    }
    intersects(range) {
        if (!range) {
            return false;
        }
        return this.range.compareBoundaryPoints(Range.START_TO_END, range) !== -1
            && this.range.compareBoundaryPoints(Range.END_TO_START, range) !== 1;
    }
    serialize(referenceElement) {
        referenceElement = referenceElement || dom_1.default(this.range.commonAncestorContainer).closest('[id]');
        return new SerializedHighlight_1.default(Object.assign({}, this.data, SerializedHighlight_1.default.defaultSerializer(this.range, referenceElement)));
    }
    loadStyle() {
        const { style } = this.data;
        if (style) {
            this.elements.forEach((element) => element.classList.add(style));
        }
    }
}
exports.default = Highlight;
//# sourceMappingURL=Highlight.js.map